@@ -7,6 +7,7 @@ import (
 	"errors"
 	"syscall"
 
+	"github.com/lmorg/murex/debug"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/state"
 	"github.com/lmorg/murex/lang/types"
@@ -27,9 +28,8 @@ func mkbg(p *lang.Process) error {
 		return errors.New("FID is not a stopped process. Run `jobs` or `fid-list` to see a list of stopped processes")
 	}
 
-	pid, cmd := f.Exec.Get()
-	if pid > 0 && cmd != nil {
-		err = cmd.Process.Signal(syscall.SIGCONT)
+	if f.SystemProcess.External() {
+		err = f.SystemProcess.Signal(syscall.SIGCONT)
 		if err != nil {
 			return err
 		}
@@ -58,21 +58,24 @@ func cmdForeground(p *lang.Process) error {
 	}
 
 	lang.HidePrompt <- true
-
-	pid, cmd := f.Exec.Get()
-	if pid > 0 && cmd != nil {
-		err = cmd.Process.Signal(syscall.SIGCONT)
-		if err != nil {
-			return err
-		}
-	}
 	go unstop(f)
-
 	updateTree(f, false)
 
 	lang.ForegroundProc.Set(f)
-
 	f.State.Set(state.Executing)
+
+	if f.SystemProcess.External() {
+		lang.UnixPidToFg(f)
+
+		err = f.SystemProcess.Signal(syscall.SIGCONT)
+		if err != nil {
+			// don't "return err" because we still want to wait for the process
+			// to finish. So lets just print a debug message instead.
+			debug.Logf("!!! failed syscall in cmdForeground()->(f: [%d] %s %s)->f.SystemProcess.Signal(syscall.SIGCONT):\n!!! error: %s",
+				f.SystemProcess.Pid(), f.Name.String(), f.Parameters.StringAll(), err.Error())
+		}
+	}
+
 	<-f.Context.Done()
 	return nil
 }
