@@ -1,4 +1,7 @@
 import { sidebar } from "vuepress-theme-hope";
+import commandsMenu from "./commands_generated.json"
+import parserMenu from "./parser_generated.json"
+import variablesMenu from "./variables_generated.json"
 
 export default sidebar({
   "/": [
@@ -34,29 +37,29 @@ export default sidebar({
     {
       text: "Operators And Tokens",
       icon: "hashtag",
-      prefix: "parser/",
-      children: "structure",
+      prefix: "/",
+      children: parserMenu,
       collapsible: true,
     },
     {
-      text: "Builtins",
+      text: "Builtin Commands",
       icon: "cubes",
-      prefix: "commands/",
-      children: "structure",
+      prefix: "/",
+      children: commandsMenu,
       collapsible: true,
     },
-    {
+    /*{
       text: "Optional Builtins",
       icon: "cube",
       prefix: "optional/",
       children: "structure",
       collapsible: true,
-    },
+    },*/
     {
-      text: "Variables",
+      text: "Special Variables",
       icon: "dollar",
-      prefix: "variables/",
-      children: "structure",
+      prefix: "/",
+      children: variablesMenu,
       collapsible: true,
     },
     {
