@@ -117,10 +117,20 @@ func (tree *ParserT) parseObject(exec bool) ([]rune, *primitives.DataType, error
 			}
 			tree.charPos++
 
+		case '(':
+			val, err := tree.parseSubExpression(exec)
+			if err != nil {
+				return nil, nil, err
+			}
+			err = o.UpdateInterface(val)
+			if err != nil {
+				return nil, nil, err
+			}
+
 		case '$':
 			switch {
 			case tree.nextChar() == '{':
-				// inline subshell
+				// inline sub-shell
 				strOrVal := varFormatting(o.stage)
 				subshell, fn, err := tree.parseSubShell(exec, r, strOrVal)
 				if err != nil {
@@ -144,12 +154,12 @@ func (tree *ParserT) parseObject(exec bool) ([]rune, *primitives.DataType, error
 			default:
 				// inline scalar
 				strOrVal := varFormatting(o.stage)
-				scalar, v, _, err := tree.parseVarScalar(exec, strOrVal)
+				scalar, val, _, err := tree.parseVarScalar(exec, strOrVal)
 				if err != nil {
 					return nil, nil, err
 				}
 				if exec {
-					err = o.UpdateInterface(v)
+					err = o.UpdateInterface(val)
 					if err != nil {
 						return nil, nil, err
 					}
@@ -163,7 +173,11 @@ func (tree *ParserT) parseObject(exec bool) ([]rune, *primitives.DataType, error
 
 		case '~':
 			// tilde
-			err := o.AppendRune([]rune(tree.parseVarTilde(exec))...)
+			home, err := tree.parseVarTilde(exec)
+			if err != nil {
+				return nil, nil, err
+			}
+			err = o.AppendRune([]rune(home)...)
 			if err != nil {
 				return nil, nil, err
 			}
