@@ -7,6 +7,12 @@ func tokeniseLine(line []rune, linePos int) ([]string, int, int) {
 		return nil, 0, 0
 	}
 
+	var adjust int
+	if linePos >= len(line) {
+		adjust = linePos - len(line) - 1
+		linePos = len(line) - 1
+	}
+
 	var index, pos int
 	var punc bool
 
@@ -44,7 +50,7 @@ func tokeniseLine(line []rune, linePos int) ([]string, int, int) {
 		}
 	}
 
-	return split, index, pos
+	return split, index, pos - adjust
 }
 
 func tokeniseSplitSpaces(line []rune, linePos int) ([]string, int, int) {
